import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import Grid from "@material-ui/core/Grid";
import Paper from "@material-ui/core/Paper";
import Table from "material-ui/Table/Table";
import TableBody from "material-ui/Table/TableBody";
import {  TableCell } from "@material-ui/core";
import { TableContainer } from "@material-ui/core";
import TableRow from "material-ui/Table/TableRow";
import MuiThemeProvider from "material-ui/styles/MuiThemeProvider";
import TextField from "@material-ui/core/TextField";
import IconButton from "@material-ui/core/IconButton";
import { Add, Remove } from "@material-ui/icons";
import { Draggable } from "react-beautiful-dnd";
import FieldFooterOptions from "./FieldFooterOptions";
import DefaultField from "./DefaultField";
import useForm from "../../contexts/useForm";
import { Typography } from "@material-ui/core";

/** CSS styles used on page components. */
const useStyles = makeStyles((theme) => ({
  paper: {
    padding: theme.spacing(3),
    width: theme.spacing(100),
    ["@media (max-width:1050px)"]: {
      width: theme.spacing(63),
      ["@media (max-width:849px)"]: {
        width: "85%",
      },
    },
    marginBottom: "2%",
    ["@media (min-width:600px)"]: {
      marginLeft: "4%",
    },
  },
  questionsGrid: {
    marginBottom: "20px",
  },
  errorGrid: {
    marginTop: "1%",
    color: "#ff4646",
    width: "80%",
    fontSize: "13px",
  },
  row: {
    display: "flex",
    flexDirection: "row",
    ["@media (max-width:600px)"]: {
      flexDirection: "column",
      marginTop: "5%",
    },
  },
  selectFormating: {
    ["@media (max-width:430px)"]: {
      minWidth: "0px",
      width: "85%",
    },
    minWidth: "250px",
  },
  subformSelect: {
    ["@media (max-width:430px)"]: {
      width: "70%",
      fontSize: "76%",
    },
  },
  excludeFormating: {
    ["@media (max-width:1050px)"]: {
      marginLeft: "40%",
    },
  },
  excludeFormatingSmall: {
    ["@media (max-width:1050px)"]: {
      marginLeft: "10%",
    },
    ["@media (max-width: 600px)"]: {
      marginLeft: "50%",
    },
  },
}));
/** Main function that returns the content of the option 'question'. */
function FormFieldTable(props) {
  /** Style class. */
  const classes = useStyles();
  /** Importing function to set table cell field value. */
  const { setCellField, setTableColumn, setTableRow } = useForm();
  return (
    <Draggable key={props.id} draggableId={props.id} index={props.idq}>
      {(provided, snapshot) => {
        return (
          <Paper
            className={classes.paper}
            ref={provided.innerRef}
            {...provided.draggableProps}
            {...provided.dragHandleProps}
          >
            <Grid container item xs={12} justify="center">
              <h4>Tabela</h4>
            </Grid>
            <Grid container>
              <DefaultField
                question={props.question}
                description={props.description}
                idq={props.idq}
                error={props.error}
              />
              <TableContainer component={Paper}>
                <MuiThemeProvider>
                  <Table aria-label="simple table">
                    <TableBody displayRowCheckbox={false}>
                      {props.table.matrix.map((row, rowNumber) => (
                        <TableRow
                          key={rowNumber + row}
                          sx={{
                            "&:last-child td, &:last-child th": { border: 0 },
                          }}
                        >
                          <TableCell style={{ width: "2%", padding: 20 }}>
                            <IconButton
                              aria-label="delete row"
                              type="submit"
                              size="small"
                              variant="contained"
                              onClick={() =>
                                setTableRow(props.idq, rowNumber, false)
                              }
                            >
                              <Remove />
                            </IconButton>
                          </TableCell>
                          {row.map((cell, columnNumber) => (
                            <TableCell component="th" align='center' scope="row">
                              <TextField
                                id="standard-basic"
                                defaultValue={cell}
                                autoComplete="off"
                                variant="outlined"
                                onBlur={(e) =>
                                  setCellField(
                                    e.target.value,
                                    props.idq,
                                    rowNumber,
                                    columnNumber
                                  )
                                }
                              />
                            </TableCell>
                          ))}
                        </TableRow>
                      ))}
                      <TableRow style={{height:"1%"}} align="center">
                      <TableCell colSpan={props.table.columns + 1} align='center' scope="row">
                        <IconButton
                            aria-label="add row"
                            type="submit"
                            size="small"
                            variant="contained"
                            onClick={() => setTableRow(props.idq, null, true)}
                          >
                            <Add />
                          </IconButton>
                      </TableCell>
                    </TableRow>
                    </TableBody>
                  </Table>
                </MuiThemeProvider>
              </TableContainer>
              <Grid
                item
                container
                direction="row"
                justify="flex-end"
                alignItems="flex-end"
                marginTop="20"
                xs={12}
                sm={4}
              >
                <FieldFooterOptions
                  idq={props.idq}
                  required={props.validation[0].value}
                />
              </Grid>
            </Grid>
          </Paper>
        );
      }}
    </Draggable>
  );
}

export default FormFieldTable;