import React, { useEffect } from "react";
import { makeStyles } from "@material-ui/core/styles";
import Grid from "@material-ui/core/Grid";
import Paper from "@material-ui/core/Paper";
import Typography from "@material-ui/core/Typography";
import Checkbox from "@material-ui/core/Checkbox";
import Table from "material-ui/Table";
import TableBody from "material-ui/Table/TableBody";
import { TableCell, TableRow } from "@material-ui/core";
import { TableContainer } from "@material-ui/core";
import MuiThemeProvider from "material-ui/styles/MuiThemeProvider";
import { useState } from "react";
import { Button } from "@material-ui/core";
import { Collapse } from "@material-ui/core";

const useStyles = makeStyles((theme) => ({
  paper: {
    padding: theme.spacing(3),
    width: theme.spacing(100),
    marginBottom: "2%",
    ["@media (max-width: 896px)"]: {
      width: "300px",
    },
  },
  questionsGrid: {
    marginBottom: "20px",
  },
  text: {
    color: "black",
  },
  button: {
    background: "#05a5dd",
    color: "white",
  },
}));

function FormFieldTable(props) {
  const classes = useStyles();
  const [indexState, setIndexState] = useState({});
  console.log(props.answers);

  const handleClick = (index) => {
    if (indexState[index] == true)
      setIndexState({ ...indexState, [index]: false });
    else setIndexState({ ...indexState, [index]: true });
    console.log(indexState);
  };

  return (
    <Paper className={classes.paper}>
      <Grid container>
        <Grid item xs={12} className={classes.questionsGrid}>
          <Typography>id: {Number(props.place)}</Typography>
          <Typography
            style={{ wordWrap: "break-word" }}
            className={classes.text}
            variant="h6"
          >
            {props.question}
          </Typography>
          <Typography style={{ wordWrap: "break-word" }} variant="h8">
            {props.description}
          </Typography>
        </Grid>
        {props.answers.map((table, index) => (
          <Grid style={{ marginBottom: "10px" }} container>
            <Button
              className={classes.button}
              variant="contained"
              onClick={() => handleClick(index)}
              fullWidth
            >
              Tabela {index}
            </Button>
            <Collapse in={indexState[index]}>
              <TableContainer component={Paper}>
                <MuiThemeProvider>
                  <Table aria-label="simple table" key={index}>
                    <TableBody displayRowCheckbox={false}>
                      {table.matrix ? (
                        table.matrix.map((row, rowNumber) => (
                          <TableRow
                            key={100 * table.id + rowNumber}
                            sx={{
                              "&:last-child td, &:last-child th": { border: 0 },
                            }}
                          >
                            {row.map((cell, columnNumber) => (
                              <TableCell component="th" scope="row">
                                {cell}
                              </TableCell>
                            ))}
                          </TableRow>
                        ))
                      ) : (
                        <Grid style={{ padding: "10px" }}>
                          <Typography
                            style={{ wordWrap: "break-word" }}
                            variant="h8"
                          >
                            Sem resposta!
                          </Typography>
                        </Grid>
                      )}
                    </TableBody>
                  </Table>
                </MuiThemeProvider>
              </TableContainer>
            </Collapse>
          </Grid>
        ))}
      </Grid>
    </Paper>
  );
}

export default FormFieldTable;
