import React, { useState, useEffect } from "react";
import { makeStyles } from "@material-ui/core/styles";
import Grid from "@material-ui/core/Grid";
import Paper from "@material-ui/core/Paper";
import TextField from "@material-ui/core/TextField";
import Typography from "@material-ui/core/Typography";
import Table from "material-ui/Table/Table";
import TableBody from "material-ui/Table/TableBody";
import { Button, TableCell } from "@material-ui/core";
import { TableContainer } from "@material-ui/core";
import TableRow from "material-ui/Table/TableRow";
import MuiThemeProvider from "material-ui/styles/MuiThemeProvider";

const useStyles = makeStyles((theme) => ({
  paper: {
    padding: theme.spacing(3),
    width: theme.spacing(100),
    height: "15%",
    ["@media (max-width:827px)"]: {
      width: "85%",
    },
    marginBottom: "12px",
  },
  questionsGrid: {
    marginBottom: "20px",
  },
  text: {
    color: "black",
  },
  validation: {
    fontSize: "14px",
    color: "red",
  },
}));

function FormFieldTable(props) {
  const classes = useStyles();

  return (
    <Paper className={classes.paper}>
      <Grid container>
        <Grid item xs={12} className={classes.questionsGrid}>
          <Typography
            style={{ wordWrap: "break-word" }}
            className={classes.text}
            variant="h6"
          >
            {props.question}
          </Typography>
          <Typography style={{ wordWrap: "break-word" }} variant="h8">
            {props.description}
          </Typography>
        </Grid>
        <TableContainer component={Paper}>
                <MuiThemeProvider>
                  <Table aria-label="simple table">
                    <TableBody displayRowCheckbox={false}>
                      {props.table.matrix.map((row, rowNumber) => (
                        <TableRow
                          key={rowNumber}
                          sx={{
                            "&:last-child td, &:last-child th": { border: 0 },
                          }}
                        >
                          {row.map((cell, columnNumber) => (
                            <TableCell component="th" scope="row">
                              {cell}
                            </TableCell>
                          ))}
                        </TableRow>
                      ))}
                    </TableBody>
                  </Table>
                  </MuiThemeProvider>
              </TableContainer>
        <Grid
          item
          container
          direction="row"
          justify="flex-end"
          alignItems="flex-end"
          xs={3}
        ></Grid>
      </Grid>
    </Paper>
  );
}

export default FormFieldTable;